%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%            A code for calibration of model parameters                   % 
%                           developed by                                  %
%                         Peyman Babakhani                                % 
%                    University of Liverpool, UK                          %
%               National Tsing Hua University, Taiwan                     %
%                    p.babakhani@liverpool.ac.uk                          %
%                        peyman.bi@yahoo.com                              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %      
%   This code is based upon the Fixed Pivot approach developed by Kumar   %
%   and Ramkrishna, 1995. The code is developed for simulating early      % 
%   and late stages of aggregation and sedimentation of nanoparticles.    % 
%                                                                         %
%   This script file reads the observation data, solves the aggregation   % 
%   and sedimentation model, and saves and plots the observation and      % 
%   modeled data.                                                         % 
%                                                                         %
%   The inputs or observation data should be in MS Excel format.          % 
%   The first sheet named "Sheet1" contains mean Z-average data (nm), the % 
%   second sheet, named "Sheet2", contains mean derived count rate data,  % 
%   and the third sheet, named "Sheet3", includes the size distribution   % 
%   data. In the Z-average datasheet the first, second, and the third     % 
%   columns contain time (min), mean Z-average (nm) for duplicate         % 
%   experiments, and standard deviations of these means, respectively.    % 
%   Similarly, in derived count rate datasheet, the first, second, and    % 
%   the third columns contain time (min), mean derived count rate, and    % 
%   standard deviation data, respectively.                                % 
%   In the size distribution datasheet the first, second, and             % 
%   the third columns contain the volume-based size distribution in the   % 
%   beginning, middle, and the end of the experiment with a duration of   % 
%   300 min, respectively. For each set of experimental curves, there     % 
%   should be three columns in every sheets.                              %
%   It should be noted that since averaging the particle size             % 
%   distributions(PSD) between duplicates can cause complicated shape of  % 
%   PSD and thereby computational problems, from the duplicate experiments%
%   only one set of data is selected for simulation and as initial        %
%   condition.                                                            %
%   All the units are in SI system. The input and output sizes are        % 
%   converted to nm. The code is able to simulate batch data of batch     %
%   aggregation expriments, each of which is placed in a separte set of   % 
%   three columns in the input data. This code is also able to plot the   %
%   concentration curves along the depth of the waster column fo each     % 
%   case.                                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!%
%   IMPORTANT NOTE: The user can use and modify this code for any         % 
%   non-commercial purposes with proper reference to the following paper: %
%   Peyman Babakhani, Jonathan Bridge, Tanapon Phenrat, Ruey-an Doong,    %   
%   and Karl R Whittle, 2018 "Aggregation and sedimentation of shattered  % 
%   graphene oxide nanoparticles (SGO) in dynamic environments: a         % 
%   solid-body rotational approach"                                       %
%   Environmental, Science: Nano                                          %
%!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;close all;clc
%%
tic;
%
 % Inputs:
%
%Assign the output file names:
FileName='GO_Cylinder_075mM_IS';
OutputFileName=FileName;
 
%Assign the number of experimental cases (the number of curves in each graph)
% if only one case of the data set is going to be modelled then assign 1 to this 
%option and select the case number in the next option:
PlotNo=1;
 
%Assign the case number of input data which is going to be modelled. If PlotNo>1, 
%then this caseNo will be ignored:
caseNo=4;
%_____________________________________________________
 
%Parameters:
%Assign the attachment efficiency:
%alfMat=[0.0 4.75e-2 5.13e-5 0.0525 31.5 8.05e-6 1.17e-2 0.01751 9.65e-6 9.9e-6 0.68088 20.34625];
alfMat=[1.064e-3 0.000122412 1.425e-3 6.825e-3 0.00065];
%Assign the fractal Dimension:
%Elements should be as many as the number of experimental cases.
%DfMat=[2.20 1.5035 1.8071 2.121 2.19 1.945 1.99 1.9404 1.9 1.91 1.9687 2.5774];
DfMat=[1.8174 1.4 2.058 2.626 1.34];
%Assign the factor for refining the initial delta_t:
%Elements should be as many as the number of experimental cases.
%deltfacMat=[2 200 100 500 100 300 300 2000 100 100 500 800];
deltfacMat=[2000 400 400 120 500];
 
%Assign time step magnification:
%Elements should be as many as the number of experimental cases.
%This factor is used to increase the time step after passing the early stage 
%of the modelling, where the model run is computationally problematic. Usually
%a value of 1000 is appropriate unless the running is slow due to slow
%aggregation, then this value can be increased, e.g., to 1000000
deltmagMat=[1000 1000 1000 1000 1000 1000 1000];
 
%Assign the portion of the simulation time period after which the time step 
%can be increased:
RelaxationPortion=1/40;
 
%Delta t factor after relaxation:
deltfacMatRelax=2;
 
%Assign the initial Concentration (mg/L)
c0=50;  %mg/L
c0=c0/1000;  %kg/m^3
 
%Assign the minimum initial hydrodynamic (Z-average) diameter observed among
%all the experimental cases (nm):
D0real=90;       %nm
D0real=D0real*10^-9;
 
%Assign the density of solids particles and the fluid (kg/m^3)
RhoS=1800;  % kg/m^3   for GO
%RhoS=3160;   % kg/m^3   for HAp
Rho=1000;    % kg/m^3   for water 
 
%Assign the experiment duration (min):
% By default, the run time is automatically selected from the experimental
% data. However, if you wish to run the model for shorter times then assign
% a value to in the following line other than 1:
T_user=1;  % min
 
%PSD snapshots time for early stage:
TT1=30;
TT1=TT1*60;  % s
 
%PSD snapshots time for late stage:
TT2=100;
TT2=TT2*60;  % s
 
%Assign the number of delta_x, or the number of delta_x that should be considered:
%Here, in order to save time of modelling, we assign this as one. Otherwise,
%since it does not affect the numerical method, selection of 10-20 intervals
%is adequate for appropriate resolution of the curve. 
ndelx=1;
%ndelx=ndelx+1;
 
%Assign the vial depth or the total depth of the water column from the surface of 
% water to the bottom of the column:
%Elements should be as many as the number of experimental cases.
dsMat=[3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3 3];
 
%Cross section area of the vial:
Across=0.01*0.01; %m^2  %for common cuvettes
 
%Measurement depth (position) of measurement(Should be smaller than dsMat)
%This is the depth where aggregation is monitored
%Elements should be as many as the number of experimental cases.
MeasDep=[2.5 2.5 2.5 2.5 2.325 2.325 2.325];   %cm
 
%Shear Rate
%Can be used to simulate the condition of the vortex before the start of 
%the measurement:
G=0;  %26.7; %(1/s) 
 
%Temperature (kelvin):
Temp=298;  %'K
 
%Viscosity:
Visc=0.00089;  %Pa.s or Kg/m/s 
 
%If ndelx>1, assign the number of plots that should be plotted for 
%concentration change along the height in the course of the experiment
plotnumber=6;
 
%Factor for further resolution of the particle size dimension discretization refinement:
%This helps obtaining higher resolution in the PSD.
%Elements should be as many as the number of experimental cases.
bin_resolut_facMat=[1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1];
 
%The total number of bins that is considered in the simulation:
%For DLS data of aggregation and sedimentation over the course of 5 hours,
%it can be considered as 100. Later this will be automatically decreased
%based on the initial PSD bins with non-zero concentration.
x_dist_data_No=100;
 
%Particle shape factor of nanoparticles for calculation of the a sedimentation velocity
%using the particles size distribution model of Kehlifa and Hill:
teta=1;    %assuming spherical particles
 
%??????????????????????????????????????????????????
%Select the collision frequency calculation method:
%??????????????????????????????????????????????????
%Collision_Calculation_mehtod=1; ----> permeability method based on Brinkman model
%Collision_Calculation_mehtod=2; ----> permeability method based on Davies Correlation
%Collision_Calculation_mehtod=3; ----> simple fractal model without permeability 
Collision_Calculation_mehtod=1;
 
%???????????????????????????????????????
%Select the velocity calculation method:
%???????????????????????????????????????
%Vel_Calculation_mehtod=1; ----> power law method
%Vel_Calculation_mehtod=2; ----> permeability method based on Davies Correlation
%Vel_Calculation_mehtod=3; ----> permeability method based on Brinkman model
%Vel_Calculation_mehtod=4; ----> particle size distribution-based model
Vel_Calculation_mehtod=1;
 
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%Reading experimental data:
Input1=xlsread('Outputs_Polydis_Compelet_Cyl_UV_Vis_300min_075mM_IS.xls', 'Sheet1');
[num,txt,raw] = xlsread('Outputs_Polydis_Compelet_Cyl_UV_Vis_300min_075mM_IS.xls', 'Sheet1'); 
 
%Reading the count rate data:
Input2=xlsread('Outputs_Polydis_Compelet_Cyl_UV_Vis_300min_075mM_IS.xls', 'Sheet2');
 
  %Reading the size distribution data:
x_initial_size_dist=xlsread('XData_Size_Distrib.xls');
obs_size_dist=xlsread('Outputs_Polydis_Compelet_Cyl_UV_Vis_300min_075mM_IS.xls', 'Sheet3');
obs_size_dist_std=xlsread('Outputs_Polydis_Compelet_Cyl_UV_Vis_300min_075mM_IS.xls', 'Sheet4');
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%% End of User Inputs %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%Reading the particle size distributions at the beginning, middle and the end
%of the experiments and finding the minimum bin size 
 
for pn=1:PlotNo
    
    if PlotNo>1
        caseNo=pn;
    end
%Reading the observed distribution and initial distribution:
   InputDistInitial(pn,:)=obs_size_dist(1:x_dist_data_No,3*caseNo-2);
   InputDistMid(pn,:)=obs_size_dist(1:x_dist_data_No,3*caseNo-1);
   InputDistEnd(pn,:)=obs_size_dist(1:x_dist_data_No,3*caseNo);
 
%Finding the minimum bin size of the initial particle size distribution
%where the the concentration is nonzero. This will be considered
%as the first bin size in the model:
        first_non_zero1=find(InputDistInitial(pn,:));
        first_non_zero2=find(InputDistMid(pn,:));
        first_non_zero3=find(InputDistEnd(pn,:));
        Initmin=first_non_zero1(1);
        midmin=first_non_zero2(1);
        Endmin=first_non_zero3(1);
        tempindx=Initmin;
        D01Mat(pn)=x_initial_size_dist(tempindx);  %nm
        D01Mat(pn)=D01Mat(pn)*10^-9;                %m
bin_resolut_fac=bin_resolut_facMat(pn);
kk=x_dist_data_No-tempindx;
kk=kk*bin_resolut_fac;
kkk(pn)=kk %This is the number of required bins that is used in each case of modelling
intiateBinNoMat(pn)=x_dist_data_No*bin_resolut_fac-kkk(pn)+1;
 
end
 
size_ditrib1=zeros(PlotNo,max(kkk));
No_size_ditrib1=zeros(PlotNo,max(kkk));
Mass_size_dist1=zeros(PlotNo,max(kkk));
 
size_ditrib2=zeros(PlotNo,max(kkk));
No_size_ditrib2=zeros(PlotNo,max(kkk));
Mass_size_dist2=zeros(PlotNo,max(kkk));
 
size_ditrib3=zeros(PlotNo,max(kkk));
No_size_ditrib3=zeros(PlotNo,max(kkk));
Mass_size_dist3=zeros(PlotNo,max(kkk));
 
 
%Reading the data number in each case:
for pn=1:PlotNo
    
        if PlotNo>1
        caseNo=pn;
        end
    
Input11=0;
Input11=Input1(:,3*caseNo-2);
%Removing NaN from the matrix 
Input11(isnan(Input11))=[];
siztemp=size(Input11);
dataNo(pn)=siztemp(1);
end
 
ConcOutputMat=zeros(PlotNo,max(dataNo));
ConcMat=zeros(PlotNo,max(dataNo),ndelx);
ModelMat=zeros(PlotNo,max(dataNo));
 
set(0,'defaultAxesFontName', '<Arial>')
set(0,'defaultTextFontName', '<Arial>')
fig=figure;
%markers={'o', 's', 'd', '^', 'v', '>','<','h', 'o', 's', 'd', '^', 'v', '>','<','h'};
%linspecific={'-', '--', ':', '-.', '-'};
 
markers=['^','^','o','o','s', '^', 'v', '>','<','h', 'o', 's', 'd', '^', 'v', '>','<','h'];
linspecific=['-','-','-.','-.',':',':', '-.', '--'];
%##########################################################################
%?????????????????????????????????????????????????????????????????????????%
%The start of the loop for the simulating every experimental data set until
%plotting the hydrodynamic size evolution 
%?????????????????????????????????????????????????????????????????????????%
for pn=1:PlotNo
   tic; 
Inputx=0;
Inputy=0;
if PlotNo>1
    caseNo=pn;
end
    
%Input variables from the input data:
    Inputx=Input1(1:dataNo(pn),3*caseNo-2);
    Inputy=Input1(1:dataNo(pn),3*caseNo-1);
    InputErr=Input1(:,3*caseNo);
    InputEr=InputErr;
    L=Inputy(:)<20;
    Inputx(L)=[];
    Inputy(L)=[];
    InputEr(L)=[];
    sizI=size(InputEr);
%number of NaN in the matrix 
    nan=isnan(InputEr);
    nnan=nnz(nan);
    net=sizI(1)-nnan;
    panj=[2*pn:5:net];
    newInputEr=zeros(sizI(1));
    panjmat=InputEr(panj);
    newInputEr(sub2ind(size(InputEr), panj'))=panjmat;
    Dgeom=0;
  
%Determining the duration of run:
  if T_user==1
   T=max(Inputx);% min
  else
   T=T_user;% min
  end
  if (T_user==1 && T<300)
      T=300;
  end
   T=T*60;  % s
   
%Selecting the Minimum possible Delta_t as around 1/1000 times of the initial Deleta_t:
    mindelt=T/100/max(deltfacMat)*60/1000;
 
    alf=alfMat(caseNo);
    Df=DfMat(caseNo);
    deltfac=deltfacMat(caseNo);
    deltmag=deltmagMat(caseNo);
 
    ds=dsMat(caseNo);
    ds=ds/100;  %m
%Calculation of delta_x
    delx=ds/(ndelx);
 
mdp=MeasDep(caseNo); %cm for the beam position in the cuvette placed in the Malvern Zetasizer DLS
mdp=mdp/100;  %m
mdpNdx=round(mdp/delx); %Cell index, which is the place of the measurement.
 
% If the number of delta_x is one then:
if ndelx==1
mdpNdx=1;
delx=mdp;
end
 
%Attributing delta t:
%deltfac=deltfacMat(pn);
deltinitial=3.3678;  %min
deltinitial=deltinitial*60;  % s
delt1=deltinitial/deltfac; 
 
ndelt0=(round(T/deltinitial)+1);
if ndelt0>dataNo(pn)
    ndelt0=dataNo(pn); 
end
    ndelt1=ndelt0*deltfac;
    
   TMat(pn)=T;
%if ndelt1>dataNo(1)*deltfac
%    ndelt1=dataNo(1)*deltfac; 
%end
 
bin_resolut_fac=bin_resolut_facMat(pn);
 
c0bin=0;
a=0;
n=0;
vsMat=zeros(ndelx,kkk(pn));
vsMat1=zeros(ndelx,kkk(pn));
vssM=0;
aMat=zeros(ndelx,kkk(pn));
aMat1=zeros(ndelx,kkk(pn));
c=zeros(ndelx,kkk(pn));
ms=zeros(ndelx,kkk(pn));
nMat=zeros(ndelx,kkk(pn));
u=zeros(kkk(pn));
VMatinit=zeros(1,kkk(pn));
radii_dist_init=zeros(kkk(pn));
c_dist_init=zeros(1,kkk(pn));
n_dist_init=zeros(1,kkk(pn));
radii_dist_init_res=0;
radii_dist_init_res1=0;
InputDistInitial_res=0;
InputDistInitial_res1=0;
Beta1=0;
dnx=zeros(ndelx,kkk(pn));
dnt=zeros(ndelx,kkk(pn));
 
 
  %Assign the Initial Delta_t:
 % tempndelt=round(T/60/3.3678)-2;
for i=1:ndelt0-1
deltinitialM(i)=(Inputx(i+1)-Inputx(i));  %min     %This is the interval used in the DLS data 
end
 
%deltinitial=mean(deltinitialM);
%deltinitial=deltinitial*60;  % s
 
%calculating the delta t:
%delt1=deltinitial/deltfac; 
%ndelt1=(round(T/deltinitial)+1)*deltfac;
%ndelt=(round(T/deltinitial)+1);
%{
if ndelt1>90*deltfac
    ndelt1=90*deltfac; 
end
%}
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
   D0=D01Mat(pn);
 
xdata=transpose(Inputx(:,1));
if max(Inputx)<299
    display('Error of lower time matrix');
    ErrorAt=pn
    shortage=299-max(Inputx)
end
 
%Determination of the start of the hydrodynamic diameter from the 
%initial condition of the experimental data:
DstTemp=Inputy(1:3,1);
DstTemp2=DstTemp(DstTemp(:)>40);
Dstart=min(DstTemp2);      %nm
Dstart=Dstart*10^-9
 
Dstartdist=sum(x_initial_size_dist(1:x_dist_data_No).*...
    transpose(InputDistInitial(pn,1:x_dist_data_No)))./sum...
    (transpose(InputDistInitial(pn,1:x_dist_data_No)));
Dstartdist=Dstartdist*10^-9;
 
%Number of bins
kk=kkk(pn);
intiateBinNo=intiateBinNoMat(pn);
VMatinit(1:kk)=0;
a(1:kk)=0;
n(1:kk)=0;
c0bin(1:kk)=0;
u(1:kk)=0;
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
%Initial total Mass:
massInitial=Across*ds*c0;           %kg 
 
% The radius of the minimum of the size distribution bins with non-zero concentration
a01=D0/2;  
 
%Assuming that for primary particles gyration radius can be obtained from DLS size based on
%Henry, Norrfors et al. 2015:
%The radius of the minimum hydrodynamic size observed among all experiments
a0real=D0real/2*gamma(2-Df^-1); 
 
%Selecting the final primary size based on the minimum of the two above
%sizes:
a0=min(a0real,a01);
 
%Initial solid Volume of primary particles (assuming spherical):
V0=4/3*3.1415*(a0)^3;
 
%Initial radius distribution:
radii_dist_init=x_initial_size_dist/2*1e-9;
 
%Distributing the sizes regarding the bin resolution factor:
for k=1:x_dist_data_No
   radii_dist_init_res1(k)=radii_dist_init(k);
   InputDistInitial_res1(k)=InputDistInitial(pn,k)/bin_resolut_fac;
 
end
%
 
indkj=0;
for k=1:x_dist_data_No
    for j=1:bin_resolut_fac
  indkj=indkj+1;
       if k==1
    radii_dist_init_res(indkj)=radii_dist_init_res1(1);
    InputDistInitial_res(indkj)=InputDistInitial_res1(1);
       else
        if indkj<=x_dist_data_No*bin_resolut_fac
    radii_dist_init_res(indkj)=radii_dist_init_res1(k-1)+j*(radii_dist_init_res1(k)-...
        radii_dist_init_res1(k-1))/bin_resolut_fac;
    InputDistInitial_res(indkj)=InputDistInitial_res1(k-1)+j*(InputDistInitial_res1(k)-...
        InputDistInitial_res1(k-1))/bin_resolut_fac;
         end
       end
    end
end
 
%Initial mass distribution assuming the particle density times the bin size times volume percentage divided by 
%the sum of percentages (100%):
c_dist_init=c0*InputDistInitial_res(intiateBinNo:bin_resolut_fac*x_dist_data_No)/...
    sum(InputDistInitial_res(intiateBinNo:bin_resolut_fac*x_dist_data_No));
 
%Initial Population of particles:
nt0=c0/(RhoS*V0);
 
%Size, volume, initial number concentration, and initial mass concentration
%of each bin that will be used in the simulation from here on:
for k=1:kk
a(k)=radii_dist_init_res(k+intiateBinNo-1);
vsMat(1:ndelx,k)=3.1415/6*(2*a0)^(3-Df)*(a(k)*2).^Df;
n((k))=c_dist_init(k)/RhoS./vsMat(1,k);
c0bin((k))=c_dist_init(k);
end
 
 
for xx=1:ndelx;
for k=1:kk
vsMat1(xx,k)=vsMat(xx,(k));   %Volume matrix
aMat(xx,k)=a(k);              %radius matrix
ms(xx,k)=RhoS*vsMat(xx,k);    %mass matrix
nMat(xx,k)=n(k);              %number concentration matrix
end
end
 
rstartdist2number=sum(a.*n)/sum(n);
rstartdist2mass=sum(a.*c0bin)/sum(c0bin);
 
%Calculation of geometric average in the initial time:
logtemp(1:kk)=log(2*aMat(1,1:kk));
Dgeom(1,1)=exp(sum(c0bin(1:kk).*(2*aMat(1,1:kk)).^3.*logtemp(1:kk))/(sum(c0bin(1:kk).*(2*aMat(1,1:kk)).^3)));
 
%Determining the ratio of the initial hydrodynamic size to the geometric 
%mean of the model output 
Init_Computed_Dstart2=rstartdist2mass*2; 
Init_Computed_DstartDeom=Dgeom(1,1);
 
LaterSizeTransRatio=Dstart/Init_Computed_Dstart2;
LaterSizeTransRatioGeom(pn)=Dstart/Init_Computed_DstartDeom
 
LaterSizeTransRatioMat(pn)=LaterSizeTransRatio
 
LaterSizeTransRatio=LaterSizeTransRatioGeom(pn);
 
%% Calculation of sedimentation velocity with various approaches
%======================================================================================================
%For the purpose of plotting, we first calculate these velocities for three 
%Df values (1.6, 2, 2.3) and then for the Df the current modelling
%problem
 
Df=1.6;
u0=2*(RhoS-Rho)*9.81*a0^2/9/Visc;
%Power Law:
DSed=Df-1;
for k=1:kk
u1(k)=u0*(aMat(1,k)./a0).^(DSed);
 
porosity(k)=1-(a(k)/a0)^(Df-3);
 
%Permeability from Davies Correlation:
permeabDa(k)=1/(16/(a(k))^2*(1-porosity(k))^1.5*(1+56*(1-porosity(k))^3));
 
kesiDa(k)=a(k)/(permeabDa(k))^0.5;
 
omegDa(k)=(2*(kesiDa(k))^2*(1-tanh(kesiDa(k))/kesiDa(k)))/(2*(kesiDa(k))^2+3*(1-tanh(kesiDa(k))/kesiDa(k)));
 
 
 
%Velocity from Johnson, Li and Logan (1996):
kesi=kesiDa;
uLogan1(k)=2*(RhoS-Rho)*9.81*a(k)^2/9/Visc*(kesi(k)/(kesi(k)-tanh(kesi(k)))+3/(2*(kesi(k))^2));
 
 
%Permeability from Brinkman:
permeabBr(k)=(2*a0)^2/72*(3+3/(1-porosity(k))-(8/(1-porosity(k))-3)^(1/3));
 
kesiBr(k)=a(k)/(permeabBr(k))^0.5;
 
omegBr(k)=(2*(kesiBr(k))^2*(1-tanh(kesiBr(k))/kesiBr(k)))/(2*(kesiBr(k))^2+3*(1-tanh(kesiBr(k))/kesiBr(k)));
 
phi=porosity(k);
% Velocity from Thill et al. (Wiesner), (2001) and Vikesland et al., 2016 
%(This is the same equation with that of Li and Logan (1996), only the permeability is different):):
uWiesner1(k)=(RhoS-Rho)*9.81*phi*(2*a(k))^2/18/Visc/omegBr(k);
 
%}
end
 
% Velocity based on size distribution from Khelifa and Hill (2006) cited by Vahedi and Gorczyca (2014):
 
    Re1=1.0293e-06;
    Re2=2.0293e-06;
    d50=0;
    m3=0;
    mF=0;
    phi=0;
 %
for k=1:kk
uKhelif1=0;
Re1=1.0293e-06;
 
    m3(k)=sum((2*a(1:k)).^3)/k;
    mF(k)=sum((2*a(1:k)).^Df)/k;
    phi(k)=m3(k)/(mF(k))^(3/Df);
    
   d50(k)=2*a(round(k/2));
 
   while abs(Re2-Re1)/Re2>0.01
    Re1=Re2;
    uKhelif1=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
    Re2=uKhelif1*2*a(k)*Rho/Visc;
   end
   
uKhel1(k)=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
 
end
%==================================================================================================
 
%======================================================================================================
 
Df=2.0;
u0=2*(RhoS-Rho)*9.81*a0^2/9/Visc;
DSed=Df-1;
for k=1:kk
  %Power Law:  
u2(k)=u0*(aMat(1,k)./a0).^(DSed);
 
porosity(k)=1-(a(k)/a0)^(Df-3);
 
%Permeability from Davies Correlation:
permeabDa(k)=1/(16/(a(k))^2*(1-porosity(k))^1.5*(1+56*(1-porosity(k))^3));
 
kesiDa(k)=a(k)/(permeabDa(k))^0.5;
 
omegDa(k)=(2*(kesiDa(k))^2*(1-tanh(kesiDa(k))/kesiDa(k)))/(2*(kesiDa(k))^2+3*(1-tanh(kesiDa(k))/kesiDa(k)));
 
%Velocity from Johnson, Li and Logan (1996):
kesi=kesiDa;
uLogan2(k)=2*(RhoS-Rho)*9.81*a(k)^2/9/Visc*(kesi(k)/(kesi(k)-tanh(kesi(k)))+3/(2*(kesi(k))^2));
 
%Permeability from Brinkman:
permeabBr(k)=(2*a0)^2/72*(3+3/(1-porosity(k))-(8/(1-porosity(k))-3)^(1/3));
 
kesiBr(k)=a(k)/(permeabBr(k))^0.5;
 
omegBr(k)=(2*(kesiBr(k))^2*(1-tanh(kesiBr(k))/kesiBr(k)))/(2*(kesiBr(k))^2+3*(1-tanh(kesiBr(k))/kesiBr(k)));
 
phi=porosity(k);
% Velocity from Thill et al. (Wiesner), (2001) and Vikesland et al., 2016 
%(This is the same equation with that of Li and Logan (1996), only the permeability is different):
uWiesner2(k)=(RhoS-Rho)*9.81*phi*(2*a(k))^2/18/Visc/omegBr(k);
 
end
 
%
% Velocity based on size distribution from Khelifa and Hill (2006) cited by Vahedi and Gorczyca (2014):
 
    Re1=1.0293e-06;
    Re2=2.0293e-06;
    d50=0;
    m3=0;
    mF=0;
    phi=0;
 %
for k=1:kk
uKhelif2=0;
Re1=1.0293e-06;
 
    m3(k)=sum((2*a(1:k)).^3)/k;
    mF(k)=sum((2*a(1:k)).^Df)/k;
    phi(k)=m3(k)/(mF(k))^(3/Df);
 
   d50(k)=2*a(round(k/2));
 
   while abs(Re2-Re1)/Re2>0.01
    Re1=Re2;
    uKhelif2=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
    Re2=uKhelif2*2*a(k)*Rho/Visc;
   end
uKhel2(k)=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
 
end
%==================================================================================================
 
%======================================================================================================
Df=2.3;
u0=2*(RhoS-Rho)*9.81*a0^2/9/Visc;
%Power Law:
DSed=Df-1;
for k=1:kk
u3(k)=u0*(aMat(1,k)./a0).^(DSed);
 
porosity(k)=1-(a(k)/a0)^(Df-3);
 
%Permeability from Davies Correlation:
permeabDa(k)=1/(16/(a(k))^2*(1-porosity(k))^1.5*(1+56*(1-porosity(k))^3));
 
kesiDa(k)=a(k)/(permeabDa(k))^0.5;
 
omegDa(k)=(2*(kesiDa(k))^2*(1-tanh(kesiDa(k))/kesiDa(k)))/(2*(kesiDa(k))^2+3*(1-tanh(kesiDa(k))/kesiDa(k)));
 
%Velocity from Johnson, Li and Logan (1996):
kesi=kesiDa;
uLogan3(k)=2*(RhoS-Rho)*9.81*a(k)^2/9/Visc*(kesi(k)/(kesi(k)-tanh(kesi(k)))+3/(2*(kesi(k))^2));
 
%Permeability from Brinkman:
permeabBr(k)=(2*a0)^2/72*(3+3/(1-porosity(k))-(8/(1-porosity(k))-3)^(1/3));
 
kesiBr(k)=a(k)/(permeabBr(k))^0.5;
 
omegBr(k)=(2*(kesiBr(k))^2*(1-tanh(kesiBr(k))/kesiBr(k)))/(2*(kesiBr(k))^2+3*(1-tanh(kesiBr(k))/kesiBr(k)));
 
phi=porosity(k);
 
% Velocity from Thill et al. (Wiesner), (2001) and Vikesland et al., 2016 
%(This is the same equation with that of Li and Logan (1996),only the permeability is different):):
uWiesner3(k)=(RhoS-Rho)*9.81*phi*(2*a(k))^2/18/Visc/omegBr(k);
 
end
 
% Velocity based on size distribution from Khelifa and Hill (2006) cited by Vahedi and Gorczyca (2014):
 
    Re1=1.0293e-06;
    Re2=2.0293e-06;
    d50=0;
    m3=0;
    mF=0;
    phi=0;
 %
for k=1:kk
uKhelif3=0;
Re1=1.0293e-06;
 
    m3(k)=sum((2*a(1:k)).^3)/k;
    mF(k)=sum((2*a(1:k)).^Df)/k;
    phi(k)=m3(k)/(mF(k))^(3/Df);
    
   d50(k)=2*a(round(k/2));
 
   while abs(Re2-Re1)/Re2>0.01
    Re1=Re2;
    uKhelif3=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
    Re2=uKhelif3*2*a(k)*Rho/Visc;
   end
uKhel3(k)=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
 
end
%==================================================================================================
 
%The current simulation case Df:
%Df======================================================================================================
u0=2*(RhoS-Rho)*9.81*a0^2/9/Visc;
Df=DfMat(caseNo);
 
%Power Law:
DSed=Df-1;
for k=1:kk
u(k)=u0*(aMat(1,k)./a0).^(DSed);
 
porosity(k)=1-(a(k)/a0)^(Df-3);
 
%Permeability using Happel cell model:
pack=0.1;
Rhob(k)=pack*(a(k)/a0)^(Df-3);
%permeab(k)=2*a0^2/9/Rhob(k)*(3-4.5*(Rhob(k))^(1/3)+4.5*(Rhob(k))^(5/3)-3*(Rhob(k))^2)/(3+2*(Rhob(k))^(5/3));
 
%Permeability from Davies Correlation:
permeabDa(k)=1/(16/(a(k))^2*(1-porosity(k))^1.5*(1+56*(1-porosity(k))^3));
 
kesiDa(k)=a(k)/(permeabDa(k))^0.5;
 
omegDa(k)=(2*(kesiDa(k))^2*(1-tanh(kesiDa(k))/kesiDa(k)))/(2*(kesiDa(k))^2+3*(1-tanh(kesiDa(k))/kesiDa(k)));
 
%Velocity from Johnson, Li and Logan (1996):
kesi=kesiDa;
uLogan(k)=2*(RhoS-Rho)*9.81*a(k)^2/9/Visc*(kesi(k)/(kesi(k)-tanh(kesi(k)))+3/(2*(kesi(k))^2));
 
%Permeability from Brinkman:
permeabBr(k)=(2*a0)^2/72*(3+3/(1-porosity(k))-(8/(1-porosity(k))-3)^(1/3));
 
kesiBr(k)=a(k)/(permeabBr(k))^0.5;
 
omegBr(k)=(2*(kesiBr(k))^2*(1-tanh(kesiBr(k))/kesiBr(k)))/(2*(kesiBr(k))^2+3*(1-tanh(kesiBr(k))/kesiBr(k)));
 
phi=porosity(k);
 
% Velocity from Thill et al. (Wiesner), (2001) and Vikesland et al., 2016 
%(This is the same equation with that of Li and Logan (1996, only the permeability is different):
uWiesner(k)=(RhoS-Rho)*9.81*phi*(2*a(k))^2/18/Visc/omegBr(k);
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Selecting the permeability model (Brinkman or Davies) for collision rate
%calculations:
%frequencies
if Collision_Calculation_mehtod==1
kesi(k)=kesiBr(k);
omeg(k)=omegBr(k);
elseif Collision_Calculation_mehtod==2
kesi(k)=kesiDa(k);
omeg(k)=omegDa(k);
elseif Collision_Calculation_mehtod==3
omeg(k)=1;
end
 
%Curvilinear Correction coefficients for collision efficiencies:
curvJ(k)=2*(kesi(k))^2+3-3*tanh(kesi(k))/kesi(k);
curvc(k)=-1/curvJ(k)*(kesi(k)^5+6*kesi(k)^3-tanh(kesi(k))/kesi(k)*(3*kesi(k)^5+6*kesi(k)^3));
curvd(k)=3/curvJ(k)*kesi(k)^3*(1-tanh(kesi(k))/kesi(k));
 
curvada(k)=1-curvd(k)/kesi(k)-curvc(k)/(kesi(k))^3;
 
if Collision_Calculation_mehtod==3
curvada(k)=1;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end
 
% Velocity based on size distribution from Khelifa and Hill (2006) cited by Vahedi and Gorczyca (2014):
 
    Re1=1.0293e-06;
    Re2=2.0293e-06;
    d50=0;
    m3=0;
    mF=0;
    phi=0;
 %
for k=1:kk
uKhelif1=0;
Re1=1.0293e-06;
 
    m3(k)=sum((2*a(1:k)).^3)/k;%   (NInitMat1(1,k));
    mF(k)=sum((2*a(1:k)).^Df)/k;%  (NInitMat1(1,k));
    phi(k)=m3(k)/(mF(k))^(3/Df);
    
   %d50(k)=(sum(vsMat(1,1:k)/k*6/(2*3.1415*(2*a0)^(3-Df))))^(1/Df);
   d50(k)=2*a(round(k/2));
 
   while abs(Re2-Re1)/Re2>0.01
    Re1=Re2;
    uKhelif1=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
    Re2=uKhelif1*2*a(k)*Rho/Visc;
   end
uKhel(k)=1/18*teta*9.81*(RhoS-Rho)/Visc*(d50(k))^(3-Df)*(2*a(k))^(Df-1)/(1+0.15*Re1^0.687)*phi(k);
 
end
%==================================================================================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Selecting the sedimentation velocity for collision frequencies:
if Vel_Calculation_mehtod==1
   % u is already specified as that calculated by the power law method
elseif Vel_Calculation_mehtod==2
    u=uLogan;
elseif Vel_Calculation_mehtod==3
    u=uWiesner;
elseif Vel_Calculation_mehtod==4
    u=uKhel;
end 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
 
nMat1=nMat;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for xx=1:ndelx
c(xx,1:kk)=c0bin(1:kk);
c1(xx,1:kk)=c0bin(1:kk);
Conc1(1,xx)=1;
end
 
dnx(1:ndelx,1:kk)=0;
%delc(1:ndelx,1:kk)=0;
tt=1;
t=0;
nobs=1;
delt=delt1;
tMat(1)=0;
nsink(1:ndelx,1:kk)=0;
csink(1:ndelx,1:kk)=0;
xad(1:ndelx,1:kk)=0;
dnxadd(1:ndelx,1:kk)=0;
msinksum(1,1:ndelx)=0;
ppindex=0;
ppMat=0;
Cdnxadd(1:ndelx,1:kk)=0;
pp=0;
%uMat(1,1:ndelx,1:kk)=u(tt,1:ndelx,1:kk);
tstarttempMat(1)=0;
%tstartMat(1)=0;
st=1;
T1=T;
tamam0=0;
tamam=0;
tamam1=0;
 
vsxMat(1:ndelx,1:kk)=V0;
vsxMat1(1:ndelx,1:kk)=V0;
%nsxMat(1:ndelx,1:kk)=0;
%nMat1(1:ndelx,1:kk)=0;
vs(1:kk)=V0;
vx(1:kk)=V0;
ns(1:kk)=V0;
 
%{
for xx=1:ndelx
size_ave(1,xx)=sum(aMat(xx,:).*nMat(xx,:))/sum(nMat(xx,:));
end
Hydr_Diam(1,1:ndelx)=0;
%uMat(1,1:ndelx,1:kk)=u(1:ndelx,1:kk);
%}
 
% Extracting the data for size distribution at initial time
size_ditrib1(caseNo,1:kk/bin_resolut_fac)=aMat(mdpNdx,1:bin_resolut_fac:kk)*10^9*2;   %/gamma(2-(real(Df))^-1);   %nm
No_size_ditrib1(caseNo,1:kk/bin_resolut_fac)=nMat(mdpNdx,1:bin_resolut_fac:kk)/sum(nMat(mdpNdx,1:bin_resolut_fac:kk));
Mass_size_dist1(caseNo,1:kk/bin_resolut_fac)=c(mdpNdx,1:bin_resolut_fac:kk)/sum(c(mdpNdx,1:bin_resolut_fac:kk));
 
%Calculating the averaged size:
for xx=1:ndelx;
logtemp(1:kk)=log(2*aMat(1,1:kk));
Dgeom(1,xx)=exp(sum(c(1,1:kk).*(2*aMat(1,1:kk)).^3.*logtemp(1:kk))/(sum(c(1,1:kk).*(2*aMat(1,1:kk)).^3)))*LaterSizeTransRatio;
 
size_ave(1,xx)=Dgeom(1,xx)/2;
end
 
Dgeom
%((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((((
%% The start of the delta_t loop:
while t<=T1 
tt=tt+1;
t=t+delt;
 
 dnvx=0;
 ss1Mat=0;
ss2Mat=0;
sxs1Mat=0;
ss2Max=0; 
 
for xx=1:ndelx
    
    vs2(1:kk)=vsMat(xx,1:kk);
    vs(1:kk)=vsMat(xx,1:kk);
    vx(1:kk)=vsMat(xx,1:kk);
    nMat1(xx,1:kk)=nMat(xx,1:kk);
 
 
for k=1:kk
 
    s1=0;
    ss1=0;
    s2=0;
    ss2=0;
    sxs1=0;
    sx1=0;
 
    
 if k==1
Beta1(1)=0; 
   s1=0;
   ss1=0;
 elseif k<kk
 
for i=1:kk
        for j=1:i
            
    if ((vx(i)+vx(j))>=vsMat(xx,k-1) && (vx(i)+vx(j))<=vsMat(xx,k+1))
%Collision Frequency calculation for the first term in the aggregation model:
    Beta1(i)=2*1.381*10^(-23)*Temp/(3*Visc)*((vs(i))^(1/Df)+(vs(j))^(1/Df))...
        *((vs(i))^(-1/Df)/omeg(i)+(vs(j))^(-1/Df)/omeg(j))...
        +(G/3.1415*V0^(1-3/Df)*(vs(i)^(1/Df)*curvada(i)^0.5+vs(j)^(1/Df)*curvada(j)^0.5)^3) ...
         +3/2*(3.1415/6)^(1/3)*V0^(2/3-2/Df)*((vs(i))^(1/Df)*curvada(i)^0.5+...
         (vs(j))^(1/Df)*curvada(j)^0.5)^2*abs(u(i)-u(j));
 
    if ((vx(i)+vx(j))>=vsMat(xx,k) && (vx(i)+vx(j))<=vsMat(xx,k+1))
    ada(k)=(vsMat(xx,k+1)-(vx(j)+vx(i)))/(vsMat(xx,k+1)-vsMat(xx,k));
 
    elseif((vx(i)+vx(j))>=vsMat(xx,k-1) && (vx(i)+vx(j))<=vsMat(xx,k))
    ada(k)=((vx(j)+vx(i))-vsMat(xx,k-1))/(vsMat(xx,k)-vsMat(xx,k-1));
    end
    if i == j
    kroneckerDelta = 1;
    else
    kroneckerDelta = 0;
    end
%Summations of the Fixed Pivot population balance equation (Kumar and Ramkrishna, 1995:
        s1=(1-0.5*kroneckerDelta)*ada(k)*Beta1(i)*nMat1(xx,j)*nMat1(xx,i);
        ss1=ss1+s1;
 
   end
   end
 
end
 elseif k==kk
 
     for i=1:kk
        for j=1:i
         if ((vx(i)+vx(j))>=vsMat(xx,k-1) && (vx(i)+vx(j))<=vsMat(xx,k))
 
             %It is assumed that the front of the concentration does
             %not reach the last bin during aggregation and sedimentation
             %processes. With using 100 bins this assumption was correct in all
             %cases of simulations up to 5 hours of experimental courses
 
        ss1=ss1+s1;
        
         end
        end
     end
 end
 
for j=1:kk
    %Collision Frequency calculation for the second term in the aggregation model:
    Beta2(j)=2*1.381*10^(-23)*Temp/(3*Visc)*((vs2(k))^(1/Df)+(vs2(j))^(1/Df))...
        *((vs2(k))^(-1/Df)/omeg(k)+(vs2(j))^(-1/Df)/omeg(j))...
        +(G/3.1415*V0^(1-3/Df)*(vs2(k)^(1/Df)*curvada(k)^0.5+vs2(j)^(1/Df)*curvada(j)^0.5)^3) ...
         +3/2*(3.1415/6)^(1/3)*V0^(2/3-2/Df)*((vs2(k))^(1/Df)*curvada(k)^0.5+...
         (vs2(j))^(1/Df)*curvada(j)^0.5)^2*abs(u(k)-u(j));
 
        s2=Beta2(j)*nMat1(xx,j);
        ss2=ss2+s2;
end
 
ss1Mat(k)=ss1;
ss2Mat(k)=ss2;
 
dnt(xx,k)=alf*ss1-alf*ss2*nMat1(xx,k);
dnx(xx,k)=-u(k)/(xx*delx)*nMat1(xx,k)*delt;
 
%Updating the population matrix:
nMat(xx,k)=nMat1(xx,k)+delt*dnt(xx,k)+dnx(xx,k);
%The particle which are removed from the system are added to the sediment bin 
%This used for latter calculation of the mass balance
nsink(xx,k)=-dnx(xx,k);
 
end
end
%The following loop prevent the number concentration matrix to become
%negative
for k=1:kk
if nMat(:,k)<1
    nMat(:,k)=0;
end
end
 
%calculation of the mass and mass concentration:
ms(:,1:kk)=RhoS*vsMat(:,1:kk);
c(:,1:kk)=nMat(:,1:kk).*ms(:,1:kk);
 
%?????????????????????????????????????????????????????????????????????????%
%Adjusting the delta_t based on the new numerical stability criteria 
%proposed by Babakhani et al., (2017):
%Finding the index of the bin to which the front of the concentration has moved
%in the current time step:
 
for k=kk:-1:1
    if nMat(:,k)>1
        break_k=k;
        break
    end
end
 
kumax=k+1;
if kumax>kk
    kumax=kk;
end
%
%Finding the maximum velocity that has occured to this end:
umax=max(max(u(1:kumax)));
ss2Max=max(max(ss2Mat(1:kumax)));
deltstb=2/(ss2Max+abs(umax)/ds); 
 
delt=min([0.9*deltstb*deltmag delt1]);
%?????????????????????????????????????????????????????????????????????????%
 
%Limiting the lower value of Delta_t to the minimum Delta_t specified in the inputs:
if delt<mindelt
delt=mindelt;
end
 
%Extracting the model output times according to the observation times in order to 
%compare mdoel outputs with the observation data later:
if delt<delt1
    if t>=nobs*deltinitial
        ttemp=t;
        t=nobs*deltinitial;
        nobs=nobs+1; 
        delt=t-(ttemp-delt);
    end
end
 
%The following loop prevent the mass concentration matrix to become
%negative
for xx=ndelx;
    for k=1:kk
        if c(xx,k)<=0
            c(xx,k)=0;
        end
    end
end
 
%Calculating the geometric mean:
for xx=1:ndelx;
logtemp(1:kk)=log(2*aMat(xx,1:kk));
Dgeom(tt,xx)=exp(sum(c(xx,1:kk).*(2*aMat(xx,1:kk)).^3.*logtemp(1:kk))/...
    (sum(c(xx,1:kk).*(2*aMat(xx,1:kk)).^3)))*LaterSizeTransRatio;
size_ave(tt,xx)=Dgeom(tt,xx)/2; 
end
%The following lines are used to calculate times in shear force is used
%to simulate the condition of the vortex before the start of the
%measurements. They should be modified if this is going to be considered:
    tstartMat(pn,st)=t-tstarttempMat(1);
    st=st+1;
 %{  
    else
        if t>=T1
            if t<3*T
            T1=T1+T;
            end
        end
end
%}
    %{
if tstarttempMat(1)==t
        T1=t+T;
%lmb(1:kk)=lmb(1:kk);
        G=0
 
        for xx=1:ndelx
         c(xx,:)=c(xx,:)/sum(c(xx,:))*sum(c0bin(:));
        end
        nMat=c./ms;
end
%}
 
%Calculation of the mass balance:
if ndelx==1
delx=ds;
end
 
        for xx=1:ndelx
        Conc1(tt,xx)=sum(c(xx,:))./sum(c0bin(:));
        msinksum(tt,xx)=sum(nsink(xx,1:kk).*ms(xx,1:kk))*Across*delx;
        end
        massBal1(tt)=sum(sum(c(:,:)))*delx*Across;
        
%Increasing the speed by increasing the Delta_t after the initial stage of
% the aggregation is passed:
if t-tstarttempMat(1)>=T*RelaxationPortion
    if tamam0==0
delt1=delt1*deltfac/deltfacMatRelax;
mindelt=mindelt/deltfac*deltfacMatRelax;
    end
        tamam0=1;
end
      
%Extracting the data for size distribution at middle time:
if t-tstarttempMat(1)>=TT1
    if tamam==0
size_ditrib2(pn,1:kk/bin_resolut_fac)=aMat(mdpNdx,1:bin_resolut_fac:kk)*10^9*2;  %nm
No_size_ditrib2(caseNo,1:kk/bin_resolut_fac)=nMat(mdpNdx,1:bin_resolut_fac:kk)/sum(nMat(mdpNdx,1:bin_resolut_fac:kk));
Mass_size_dist2(caseNo,1:kk/bin_resolut_fac)=c(mdpNdx,1:bin_resolut_fac:kk)/sum(c(mdpNdx,1:bin_resolut_fac:kk));
    end
        tamam=1;
end
 
%Extracting the data for size distribution at the end time:
if t-tstarttempMat(1)>=TT2
        if tamam1==0
size_ditrib3(pn,1:kk/bin_resolut_fac)=aMat(mdpNdx,1:bin_resolut_fac:kk)*10^9*2; %nm
No_size_ditrib3(caseNo,1:kk/bin_resolut_fac)=nMat(mdpNdx,1:bin_resolut_fac:kk)/sum(nMat(mdpNdx,1:bin_resolut_fac:kk));
Mass_size_dist3(caseNo,1:kk/bin_resolut_fac)=c(mdpNdx,1:bin_resolut_fac:kk)/sum(c(mdpNdx,1:bin_resolut_fac:kk));
    end
        tamam1=1;
end
 
tMat(tt)=t;
 
%Limiting the maximum number of time steps to 500000:
if tt>500000
    Massage='Number of time steps exceeds 10000'
    break
end
 
%Showing the simulation progress, (percentage remained):
Run_Time_Remained_Percent=(T-t)/T*100
 
 
%Terminating the run if any of the following occurs:
if isnan(t)==1
   Massage='Error: Instability problem, time is going wrong'
    break
end
 
if isreal(t)==0
   Massage='Error: Instability problem, time is going wrong (imaginary number)'
    break
end
 
end
%This was the end of the time step loop
%))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))))
%% 
%This for finding the real initial time when the initial vortex condition is involved:
earlyt(pn)=tstarttempMat(1)
ttstart=tt-st+2;
if st<=2
    st=tt;
    ttstart=1;
    tstartMat(pn,:)=tMat;
else
    st=st-1;
end
 
%Continue of the calculation of the mass balance error:
sinkCumulut=0;
for ttt=1:st
mass_sinkTotal(ttt)=sum(msinksum(ttstart-1+ttt,:));
sinkCumulut=sinkCumulut+mass_sinkTotal(ttt);
SedimentCumul(ttt)=sinkCumulut;
SedMassratio(ttt)=SedimentCumul(ttt)/massInitial*100;  %Percent
 
end
MassBalratio(1:st)=massBal1(ttstart:tt)/massInitial*100;  %Percent
MassBalratio(st)=MassBalratio(st);
SedMassratio(st)=SedMassratio(st);
finalMassBalance=MassBalratio(st)+SedMassratio(st);  % Should be 100 Percent
finalMassBalanceError(pn)=100-finalMassBalance  % Should be 100 Percent
 
%calculation of characteristics time (taw) (Chapter 6 of Elimelech et al.,
%1995):
taw=1/(nt0*4*1.381*10^(-23)*Temp/(3*Visc));
 
%Calculating the averaged size:
for ttt=1:st
size_out(ttt,1:ndelx)=size_ave(ttstart-1+ttt,1:ndelx);
end
 
%extracting the observation data from outputs
%tOutput=0:deltinitial:(ndelt1/deltfac-1)*deltinitial;
 
tOutput=Inputx;
 
for i=1:dataNo(pn)
tmp = abs(tstartMat(pn,1:st)-tOutput(i)*60);
[idx idx] = min(tmp); %index of closest value
t_indexoutput(i)=idx; %closest value
 
 tmatch_out(pn,i)=tstartMat(idx)/60;   %min
 
end
Size_Output=2*size_out(t_indexoutput,mdpNdx)*10^9;   %/gamma(2-(real(Df))^-1);   %nm
Size_Output=transpose(Size_Output); 
modeled=Size_Output;
 
for ttt=1:st
Conc(ttt,1:ndelx)=Conc1(ttstart-1+ttt,1:ndelx);
end
 
%Size distribution:
snapshotconc2=round(t_indexoutput(dataNo(pn))/2);
snapshotconc3=round(t_indexoutput(dataNo(pn)));
ConcInit(1:ndelx,caseNo)=Conc(1,1:ndelx);
ConcMid(1:ndelx,caseNo)=Conc(snapshotconc2,1:ndelx);
ConcEnd(1:ndelx,caseNo)=Conc(snapshotconc3,1:ndelx);
 
ConcOutput=0;
ConcOutput=Conc(t_indexoutput,mdpNdx);
ConcOutputMat(caseNo,1:dataNo(pn))=ConcOutput(1:dataNo(pn));
ConcMat(caseNo,1:dataNo(pn),1:ndelx)=ConcOutput(1:dataNo(pn));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting the results and calcualtion of the fittig R_Square:
 
    % R-Square Nash and Sutcliffe:
    meanoutput= mean(Inputy(1:dataNo(pn)));
    obsminumin= Inputy(1:dataNo(pn)) - meanoutput;
    obsminuminsq=obsminumin.*obsminumin;
    calcminuobs= transpose(modeled(1:dataNo(pn))) - Inputy(1:dataNo(pn));
    calcminuobssq= calcminuobs.*calcminuobs;
    %number of inputs
    elem=size(Inputy(1:dataNo(pn)));
    sumationo=0;
    sumationc=0;
    for hi=1:elem(1)
        sumationo=sumationo+obsminuminsq(hi);
        sumationc=sumationc+calcminuobssq(hi);
    end
    obsminuminsqs=sumationo;
    calcminuobssqs= sumationc;
    Rsq(pn)=1-(calcminuobssqs/obsminuminsqs)
 
color1='kkrrbgcm';
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
   
   if (pn==1||pn==2)
   linspecific=['-'];
   elseif (pn==3||pn==4)
             
   linspecific=['-.']; 
    elseif (pn==5)
    linspecific=['--']
   else 
    linspecific=['-'];
   end
    
       if pn<PlotNo
                   if pn<3
h(pn)=semilogy(Inputx(1:dataNo(pn)),Inputy(1:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',10, 'LineWidth', 1.7);
hold on
                   else 
h(pn)=semilogy(Inputx(1:dataNo(pn)),Inputy(1:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerFaceColor',color,'MarkerSize',5, 'LineWidth', 1.5);
 
                   end
       else
       h(pn)=semilogy(Inputx(1:2:dataNo(pn)),Inputy(1:2:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',3, 'LineWidth', 1.5);        
 
 
       end
 
    if pn==PlotNo
for j=1:2:dataNo(pn)
    if newInputEr(j)~=0
 
        %Scaling the error bars to log:
ax = get(fig,'CurrentAxes');
set(ax,'YScale','log')
 
errorbar(Inputx(j), Inputy(j), newInputEr(j), 'color',color,...
   'LineStyle','none','LineWidth',1.6);
 
%Scaling the error bars to log:
ax = get(fig,'CurrentAxes');
set(ax,'YScale','log')
 
    end
end
    end
 
hold on
 
sizex=size(xdata);
for jj=2:sizex(2)-1 
deldelt=xdata(jj+1)-xdata(jj);
delt=mean(deldelt);
end
 
ModelMat(1:dataNo(pn),caseNo)=modeled(1:dataNo(pn));
 
       if pn<PlotNo
h(pn+PlotNo)=semilogy(Inputx(1:dataNo(pn)),modeled(1:dataNo(pn)),'color',color,...
    'LineStyle',linspecific,'LineWidth', 1.8);
       else
h(pn+PlotNo)=semilogy(Inputx(1:dataNo(pn)),modeled(1:dataNo(pn)),'color',color,...
    'LineStyle',linspecific,'LineWidth', 1.8);
       end
 
       
       
       
maxsize(pn)=max(Inputy(1:dataNo(pn)));
RuningTimeMat(pn)=toc/60;   %min
end
 
%
%??????????????????????????????????????????????????????????????????????????%
%This is the end of the loop that model various experimental cases. The rest
%of the graphs are plotted separately as follows
%??????????????????????????????????????????????????????????????????????????%
%%
Rsq=Rsq
 
maxmax=max(maxsize);
ylimitax=55*maxmax;
 
ax = get(fig,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2,'FontSize',14);%,...
 
T=max(TMat);
axis([-5 350 -50 2.6e3])
set(gca,'XTick', [0 50 100 150 200 250 300 350])
set(gca, 'YTick', [0 100 250 500 1000 1500])
 
Obs_Model_axistitle='D_{H} (nm)';
 
ylabel(Obs_Model_axistitle,'FontName','Arial','FontSize',18,'FontWeight','bold');
xlabel('Time (min)','FontName','Arial','FontSize',18,'FontWeight','bold');
 
set(gca,'FontName','Arial','FontSize',16,'FontWeight','bold')
 
%legend column
columntitle=txt;
%removing the empty cells
columntitle2=columntitle(~cellfun('isempty',columntitle));
LegFit(1:PlotNo)={' Obs.'};
LegFit2(1:PlotNo)={' Model'};
 
for i=1:PlotNo
columntitle3(i)=strcat(columntitle2(i),LegFit(i));
end
 
for i=1:PlotNo
columntitle4(i)=strcat(columntitle2(i),LegFit2(i));
end
 
 
ah=axes('position',get(gca,'position'),...
            'visible','off');
legend(ah,h(1:2:PlotNo),columntitle2(1:2:PlotNo),'FontName','Arial','FontSize',14,'FontWeight','bold','location','Northwest')
legend('boxoff')
 
 
%{
legend(h(1:2:PlotNo),columntitle3(1:2:PlotNo),'FontName','Arial','FontSize',9,'FontWeight','bold','location','Northwest')
legend('boxoff')
 
ah1=axes('position',get(gca,'position'),...
            'visible','off');
legend(ah1,h(1+PlotNo:2:2*PlotNo),columntitle4(1:2:PlotNo),'FontName','Arial','FontSize',9,'FontWeight','bold','location','Northeast')
legend('boxoff')
%}
hold off
print('-dtiff','-r500',['ObsMod__' num2str(FileName)]);
%%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%Plotting the modelled concentration (dimensionless) vs observed count rate
%(dimensionless):
fig2=figure;
for pn=1:PlotNo
 
    if PlotNo>1
        caseNo=pn;
    end
 
    Inputx=Input2(1:dataNo(pn),3*caseNo-2);
    Inputy=Input2(1:dataNo(pn),3*caseNo-1)/Input2(1,3*caseNo-1);
    InputErr=Input2(:,3*caseNo)/Input2(1,3*caseNo-1);
    InputEr=InputErr;
    L=Inputy(:)<0;
    Inputx(L)=[];
    Inputy(L)=[];
    InputEr(L)=[];
    sizI=size(InputEr);
 
  nan=isnan(InputEr);
  nnan=nnz(nan);
  net=sizI(1)-nnan;
        panj=[2*pn:5:net];
        newInputEr=zeros(sizI(1));
        panjmat=InputEr(panj);
        newInputEr(sub2ind(size(InputEr), panj'))=panjmat;
 
    % R-Square Nash and Sutcliffe:
    meanoutput= mean(Inputy(1:dataNo(pn)));
    obsminumin= Inputy(1:dataNo(pn)) - meanoutput;
    obsminuminsq=obsminumin.*obsminumin;
    calcminuobs= transpose(ConcOutputMat(caseNo,(1:dataNo(pn)))) - Inputy(1:dataNo(pn));
    calcminuobssq= calcminuobs.*calcminuobs;
    %number of inputs
    elem=size(obsminuminsq);
    sumationo=0;
    sumationc=0;
    for hi=1:elem(1);
        sumationo=sumationo+obsminuminsq(hi);
        sumationc=sumationc+calcminuobssq(hi);
    end
    obsminuminsqs=sumationo;
    calcminuobssqs= sumationc;
 
    RsqConc(pn)=1-(calcminuobssqs/obsminuminsqs)
 
%Plotting the Figure:
 
color1='kkrrbgcm';
 
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
    
      if (pn==1||pn==2)
   linspecific=['-'];
   elseif (pn==3||pn==4)
   linspecific=['-.']; 
    elseif (pn==5)
    linspecific=['--']
   else 
    linspecific=['-'];
   end
   
   
   
    if pn<PlotNo
      
        if pn<3
h2(pn)=plot(Inputx(1:dataNo(pn)),Inputy(1:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',10, 'LineWidth', 1.7);
hold on
        else
 
h2(pn)=plot(Inputx(1:dataNo(pn)),Inputy(1:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerFaceColor',color,'MarkerSize',5, 'LineWidth', 1.5);
        end
 
    else
 
     h2(pn)=plot(Inputx(1:2:dataNo(pn)),Inputy(1:2:dataNo(pn)),markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',3, 'LineWidth', 1.5);
          
       end
 
 
    if pn==PlotNo
for j=1:2:dataNo(pn)
    if newInputEr(j)~=0
 
%Scaling the error bars to log:
%ax = get(fig2,'CurrentAxes');
%set(ax,'YScale','log')
 
%errorbar(Inputx(j), Inputy(j), newInputEr(j), 'color',color,...
 %  'LineStyle','none','LineWidth',1.6);
 
%Scaling the error bars to log:
%ax = get(fig2,'CurrentAxes');
%set(ax,'YScale','log')
    end
end
    end
    
hold on
 
sizex=size(xdata);
for jj=2:sizex(2)-1 
deldelt=xdata(jj+1)-xdata(jj);
delt=mean(deldelt);
end
 
for jj=1:sizex(2)
t(1:sizex(2))=jj*delt;
end
 
       if pn<PlotNo
h2(pn+PlotNo)=plot(Inputx(1:dataNo(pn)),ConcOutputMat(caseNo,1:dataNo(pn)),'color',color,...
    'LineStyle',linspecific,'LineWidth', 1.8);
       else
h2(pn+PlotNo)=plot(Inputx(1:dataNo(pn)),ConcOutputMat(caseNo,1:dataNo(pn)),'color',color,...
    'LineStyle',linspecific,'LineWidth', 1.8);
       end
       
maxsize(pn)=max(Inputy(1:dataNo(pn)));
 
 
end
%{
x2 = [Inputx(1:dataNo(1)), fliplr(Inputx(1:dataNo(2)))];
inBetween = [ConcOutputMat(1,1:dataNo(1)), fliplr(ConcOutputMat(2,1:dataNo(2)))];
fill(x2, inBetween, 'g');
 
x3 = [Inputx(1:dataNo(3)), fliplr(Inputx(1:dataNo(4)))];
inBetween2 = [ConcOutputMat(3,1:dataNo(3)), fliplr(ConcOutputMat(4,1:dataNo(4)))];
fill(x3, inBetween2, 'b');
 
maxmax=max(maxsize);
ylimitax=max(2*maxmax, 4);
%}
%handle=title('Cs Effect','fontweight','bold','Fontsize', 16);
%set(handle,'Position',[v(2)*0.43 v(4)*.8 0]);
 
ax = get(fig,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2,'FontSize',14);%,...
    %'FontSize',12);
%set(alllines,'Linewidth',2);
%set(alltext,'FontName','Arial','FontWeight','Bold','FontSize',12);
%set(allaxes,'FontName','Arial','FontWeight','Bold','FontSize',14);
%
axis([-5 350 0.75 1.25])
 
set(gca,'XTick', [0 50 100 150 200 250 300])
set(gca, 'YTick', [0 0.5 0.6 0.7 0.8 0.9 1 1.1 1.2 1.3 1.4 1.5])
 
 
 
 
Obs_Model_axistitle='C/C_{0}';
%grid on
ylabel(Obs_Model_axistitle,'FontName','Arial','FontSize',18,'FontWeight','bold');
xlabel('Time (min)','FontName','Arial','FontSize',18,'FontWeight','bold');
%set(gca,'FontName','times','FontSize',12)
set(gca,'FontName','Arial','FontSize',16,'FontWeight','bold')
 
set(gca,'XMinorTick','on','YMinorTick','off')
%{
%legend column
columntitle=txt;
%removing the empty cells
columntitle2=columntitle(~cellfun('isempty',columntitle));
LegFit(1:PlotNo)={' Obs.'};
LegFit2(1:PlotNo)={' Model'};
 
for i=1:PlotNo
columntitle3(i)=strcat(columntitle2(i),LegFit(i));
end
 
for i=1:PlotNo
columntitle4(i)=strcat(columntitle2(i),LegFit2(i));
end
 
ah=axes('position',get(gca,'position'),...
            'visible','off');
legend(ah,h2(1:2:PlotNo),columntitle3(1:2:PlotNo),'FontName','Arial','FontSize',14,'FontWeight','bold','location','Northwest')
legend('boxoff')
 
ah1=axes('position',get(gca,'position'),...
            'visible','off');
legend(ah1,h2(1+PlotNo:2:2*PlotNo),columntitle4(1:2:PlotNo),'FontName','Arial','FontSize',9,'FontWeight','bold','location','west')
legend('boxoff')
%}
hold off
print('-dtiff','-r500',['Final_Conc__' num2str(FileName)]);
 
%%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%Ploting the particle size distribution (mass-based percentage) (at initial time):
fig4=figure;
 
 
for pn=1:2:PlotNo
    if PlotNo>1
        caseNo=pn;
    end
color1='kkrrbgcm';
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
   
   if (pn==1||pn==2)
   linspecific=['-'];
   elseif (pn==3||pn==4)
             
   linspecific=['-.']; 
    elseif (pn==5)
    linspecific=['-']
   else 
    linspecific=['--'];
   end         
 
 
%Model plot:
%At initial time:
h4(pn)=semilogx(size_ditrib1((caseNo),:),...
    Mass_size_dist1((caseNo),:)*100,'LineStyle',linspecific,'color',color,...
    'LineWidth', 3);
hold on
 
% Observation plot:
h4(PlotNo+pn)=semilogx(x_initial_size_dist(1:x_dist_data_No),...
    InputDistInitial(pn,1:x_dist_data_No)/sum...
    (InputDistInitial(pn,1:x_dist_data_No))*100,markers(pn),...
    'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',6, 'LineWidth', 2);
maxsize(pn)=max(Mass_size_dist1(:,(caseNo)));
end
 
plottitle=(['Start (t = 0)']);
title(plottitle, 'fontsize',14,'FontWeight','bold');
%t.Color = 'red';
 
maxmax=max(maxsize);
ylimitax=3*maxmax;
 
%handle=title('Cs Effect','fontweight','bold','Fontsize', 16);
%set(handle,'Position',[v(2)*0.43 v(4)*.8 0]);
 
ax = get(fig,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2,'FontSize',14);%,...
    %'FontSize',12);
%set(alllines,'Linewidth',2);
%set(alltext,'FontName','Arial','FontWeight','Bold','FontSize',14);
%set(allaxes,'FontName','Arial','FontWeight','Bold');
%
axis([1e1 1e4 -2 35])
%set(gca,'XTick', 0:200:(x_initial_size_dist(x_dist_data_No)));
set(gca, 'XTick', [10^1 10^2 10^3 10^4 10^5])
set(gca,'XMinorTick','on','YMinorTick','on')
 
Obs_Model_axistitle='Mass Conc. (%)';
%axis([-1 inf 0 inf])
%grid on
ylabel(Obs_Model_axistitle,'FontName','Arial','FontSize',18,'FontWeight','bold');
xlabel('Size (nm)','FontName','Arial','FontSize',18,'FontWeight','bold');
set(gca,'FontName','times','FontSize',16)
 
%legend column
columntitle=txt;
%removing the empty cells
columntitle2=columntitle(~cellfun('isempty',columntitle));
LegFit(1:2:PlotNo)={'_ Model'};
 
%{
for i=1:2:PlotNo
columntitle3(i)=strcat(columntitle2(i),LegFit(i));
end
 
ah1=axes('position',get(gca,'position'),...
            'visible','off');
legend(ah1,h4(1:2:PlotNo),columntitle3(1:2:PlotNo),'FontName','t','FontSize',12,'FontWeight','bold','location','Northeast')
legend('boxoff')
 
%}
ah=axes('position',get(gca,'position'),...
            'visible','off');
LegFit2(1:PlotNo)={'_ Obs.'};
 
for i=1:PlotNo
columntitle4(i)=strcat(columntitle2(i),LegFit2(i));
end
 
 
legend(ah,h4(PlotNo+1:2:2*PlotNo),columntitle4(1:2:PlotNo),'FontName','t','FontSize',12,'FontWeight','bold','location','Northwest')
legend('boxoff')
%
 
hold off
print('-dtiff','-r500',['Size_Distrib_mass_based_Initial' num2str(FileName)]);
%%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%Ploting the size distribution (mass-based percentage) (at middle time):
fig5=figure;
 
for pn=1:2:PlotNo
    if PlotNo>1
        caseNo=pn;
    end
color1='kkrrbgcm';
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
   
   if (pn==1||pn==2)
   linspecific=['-'];
   elseif (pn==3||pn==4)
             
   linspecific=['-.']; 
    elseif (pn==5)
    linspecific=['-']
   else 
    linspecific=['--'];
   end
 
%Model plot:
%At mid time:
h5(pn)=semilogx(size_ditrib2(pn,:),...
    Mass_size_dist2((caseNo),:)*100,'LineStyle',linspecific,'color',color,...
    'LineWidth', 3);
hold on
 
% Obs plot:
h5(pn+PlotNo)=semilogx(x_initial_size_dist(1:x_dist_data_No),...
    InputDistMid(pn,1:x_dist_data_No)/sum(InputDistMid(pn,...
    1:x_dist_data_No))*100,markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',6, 'LineWidth', 2);
 
end
 
plottitle=(['Mid. (t = 30 min)']);
title(plottitle, 'fontsize',14,'FontWeight','bold');
%t.Color = 'r';
 
maxmax=max(maxsize);
ylimitax=3*maxmax;
 
%handle=title('Cs Effect','fontweight','bold','Fontsize', 16);
%set(handle,'Position',[v(2)*0.43 v(4)*.8 0]);
 
ax = get(fig,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2,'FontSize',14);%,...
    %'FontSize',12);
%set(alllines,'Linewidth',2);
%set(alltext,'FontName','Arial','FontWeight','Bold','FontSize',14);
%set(allaxes,'FontName','Arial','FontWeight','Bold');
%
axis([1e1 1e4 -2 35])
%set(gca,'XTick', 0:200:(x_initial_size_dist(x_dist_data_No)));
set(gca, 'XTick', [10^1 10^2 10^3 10^4 10^5])
set(gca,'XMinorTick','on','YMinorTick','on')
 
Obs_Model_axistitle='Mass Conc. (%)';
%axis([-1 inf 0 inf])
%grid on
ylabel(Obs_Model_axistitle,'FontName','Arial','FontSize',18,'FontWeight','bold');
xlabel('Size (nm)','FontName','Arial','FontSize',18,'FontWeight','bold');
set(gca,'FontName','times','FontSize',16)
%{
%legend column
columntitle=txt;
%removing the empty cells
columntitle2=columntitle(~cellfun('isempty',columntitle));
LegFit(1:PlotNo)={'_ Model'};
 
 
for i=1:PlotNo
columntitle3(i)=strcat(columntitle2(i),LegFit(i));
end
 
ah1=axes('position',get(gca,'position'),...
            'visible','off');
        
legend(ah1,h5(1:PlotNo),columntitle3(1:PlotNo),'FontName','t','FontSize',10,'FontWeight','bold','location','Northeast')
legend('boxoff')
 
ah=axes('position',get(gca,'position'),...
            'visible','off');
LegFit2(1:PlotNo)={'_ Obs.'};
 
for i=1:PlotNo
columntitle4(i)=strcat(columntitle2(i),LegFit2(i));
end
 
legend(ah,h5(PlotNo+1:2*PlotNo),columntitle4(1:PlotNo),'FontName','t','FontSize',10,'FontWeight','bold','location','Northwest')
legend('boxoff')
%}
hold off
print('-dtiff','-r500',['Size_Distrib_mass_based_MidTime' num2str(FileName)]);
%%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%Ploting the size distribution (mass-based percentage) (at end time):
fig6=figure;
 
 for pn=1:2:PlotNo
    if PlotNo>1
        caseNo=pn;
    end
color1='kkrrbgcm';
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
   
   if (pn==1||pn==2)
   linspecific=['-'];
   elseif (pn==3||pn==4)
             
   linspecific=['-.']; 
    elseif (pn==5)
    linspecific=['-']
   else 
    linspecific=['--'];
   end
%Model plot:
%At the end:
h6(pn)=semilogx(size_ditrib3(pn,:),...
    Mass_size_dist3((caseNo),:)*100, 'LineStyle',linspecific,'color',color,...
    'LineWidth', 3);
 
hold on
%Obs plot:
h6(pn+PlotNo)=semilogx(x_initial_size_dist(1:x_dist_data_No),...
    InputDistEnd(pn,1:x_dist_data_No)/sum(InputDistEnd(pn,...
    1:x_dist_data_No))*100,markers(pn),'color',color,'LineStyle','none',...
    'MarkerEdgeColor',color,'MarkerSize',6, 'LineWidth', 2);
 end
 
plottitle=(['End (t = 100 min)']);
title(plottitle, 'fontsize',14,'FontWeight','bold');
%t.Color = 'red';
 
maxmax=max(maxsize);
ylimitax=3*maxmax;
 
%handle=title('Cs Effect','fontweight','bold','Fontsize', 16);
%set(handle,'Position',[v(2)*0.43 v(4)*.8 0]);
 
ax = get(fig,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2,'FontSize',14);%,...
    %'FontSize',12);
%set(alllines,'Linewidth',2);
%set(alltext,'FontName','Arial','FontWeight','Bold','FontSize',14);
%set(allaxes,'FontName','Arial','FontWeight','Bold');
%
axis([1e1 1e4 -2 35])
%set(gca,'XTick', 0:200:(x_initial_size_dist(x_dist_data_No)));
set(gca, 'XTick', [10^1 10^2 10^3 10^4 10^5])
set(gca,'XMinorTick','on','YMinorTick','on')
 
Obs_Model_axistitle='Mass Conc. (%)';
%axis([-1 inf 0 inf])
%grid on
ylabel(Obs_Model_axistitle,'FontName','Arial','FontSize',18,'FontWeight','bold');
xlabel('Size (nm)','FontName','Arial','FontSize',18,'FontWeight','bold');
set(gca,'FontName','times','FontSize',16)
%{
%legend column
columntitle=txt;
%removing the empty cells
columntitle2=columntitle(~cellfun('isempty',columntitle));
LegFit(1:PlotNo)={'_ Model'};
 
ah1=axes('position',get(gca,'position'),...
            'visible','off');
for i=1:PlotNo
columntitle3(i)=strcat(columntitle2(i),LegFit(i));
end
legend(ah1,h6(1:PlotNo),columntitle3(1:PlotNo),'FontName','t','FontSize',10,'FontWeight','bold','location','Northeast')
legend('boxoff')
 
ah=axes('position',get(gca,'position'),...
            'visible','off');
LegFit2(1:PlotNo)={'_ Obs.'};
 
for i=1:PlotNo
columntitle4(i)=strcat(columntitle2(i),LegFit2(i));
end
 
 
legend(ah,h6(PlotNo+1:2*PlotNo),columntitle4(1:PlotNo),'FontName','t','FontSize',10,'FontWeight','bold','location','Northwest')
legend('boxoff')
%}
hold off
print('-dtiff','-r500',['Size_Distrib_mass_based_Endtime' num2str(FileName)]);
%%
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%Ploting Sedimentation Velocity figure:
 
color1='kbrgcm';
fig10=figure;
 
%Df=1.6
vel_size(1)=loglog(aMat(1,1:kk)*1e9,u1(1:kk)*6000,markers(1),'color',color1(1),'LineStyle','none',...
    'MarkerEdgeColor',color1(1),'MarkerSize',6, 'LineWidth', 2);
hold on
vel_size(4)=loglog(aMat(1,1:kk)*1e9,uLogan1(1:kk)*6000,markers(3),'color',color1(1),'LineStyle','none',...
    'MarkerEdgeColor',color1(1),'MarkerSize',6, 'LineWidth', 2);
vel_size(7)=loglog(aMat(1,1:kk)*1e9,uWiesner1(1:kk)*6000,markers(4),'color',color1(1),'LineStyle','none',...
    'MarkerEdgeColor',color1(1),'MarkerSize',6, 'LineWidth', 2);
vel_size(10)=loglog(aMat(1,1:kk)*1e9,uKhel1(1:kk)*6000,markers(5),'color',color1(1),'LineStyle','none',...
    'MarkerEdgeColor',color1(1),'MarkerSize',6, 'LineWidth', 2);
 
%Df=2.0
vel_size(2)=loglog(aMat(1,1:kk)*1e9,u2(1:kk)*6000,markers(1),'color',color1(2),'LineStyle','none',...
    'MarkerEdgeColor',color1(2),'MarkerSize',6, 'LineWidth', 2);
vel_size(5)=loglog(aMat(1,1:kk)*1e9,uLogan2(1:kk)*6000,markers(3),'color',color1(2),'LineStyle','none',...
    'MarkerEdgeColor',color1(2),'MarkerSize',6, 'LineWidth', 2);
vel_size(8)=loglog(aMat(1,1:kk)*1e9,uWiesner2(1:kk)*6000,markers(4),'color',color1(2),'LineStyle','none',...
    'MarkerEdgeColor',color1(2),'MarkerSize',6, 'LineWidth', 2);
vel_size(11)=loglog(aMat(1,1:kk)*1e9,uKhel2(1:kk)*6000,markers(5),'color',color1(2),'LineStyle','none',...
    'MarkerEdgeColor',color1(2),'MarkerSize',6, 'LineWidth', 2);
 
%Df=2.3
vel_size(3)=loglog(aMat(1,1:kk)*1e9,u3(1:kk)*6000,markers(1),'color',color1(3),'LineStyle','none',...
    'MarkerEdgeColor',color1(3),'MarkerSize',6, 'LineWidth', 2);
vel_size(6)=loglog(aMat(1,1:kk)*1e9,uLogan3(1:kk)*6000,markers(3),'color',color1(3),'LineStyle','none',...
    'MarkerEdgeColor',color1(3),'MarkerSize',6, 'LineWidth', 2);
vel_size(9)=loglog(aMat(1,1:kk)*1e9,uWiesner3(1:kk)*6000,markers(4),'color',color1(3),'LineStyle','none',...
    'MarkerEdgeColor',color1(3),'MarkerSize',6, 'LineWidth', 2);
vel_size(12)=loglog(aMat(1,1:kk)*1e9,uKhel3(1:kk)*6000,markers(5),'color',color1(3),'LineStyle','none',...
    'MarkerEdgeColor',color1(3),'MarkerSize',6, 'LineWidth', 2);
 
ax = get(fig10,'CurrentAxes');
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2);
 
set(allaxes,'FontName','Arial','FontWeight','Bold','FontSize',12);
 
maxmax=max([u1 uLogan1 uWiesner1 uKhel1 u2 uLogan2 uWiesner2 uKhel2 u3 uLogan3 uWiesner3 uKhel3]);
ymax=10000*(maxmax);
axis([-5 inf 0 ymax])
 
ylabel('Sedimentation Velocity (cm/min)','FontName','Arial','FontSize',14,'FontWeight','bold');
xlabel('Hydrodynamic Radius (nm)','FontName','Arial','FontSize',14,'FontWeight','bold');
 
set(gca,'FontName','Arial','FontSize',14,'FontWeight','bold')
 
%legend column
ptitle={'Power Law', 'Simple Fractal', 'Permeability, Davies', 'Permeability, Brinkman', 'Fractal, Size Distribution'}; 
 
ptitle={'Power law, D_{f}=1.6', 'Power law, D_{f}=2.0','Power law, D_{f}=2.3',...
    'Permeability, Davies, D_{f}=1.6','Permeability, Davies, D_{f}=2.0', 'Permeability, Davies, D_{f}=2.3','Permeability, Brinkman, D_{f}=1.6','Permeability, Brinkman, D_{f}=2.0','Permeability, Brinkman, D_{f}=2.3',...
    'Size Distribution, D_{f}=1.6','Size Distribution, D_{f}=2.0','Size Distribution, D_{f}=2.3'};
 
legend(vel_size(1:9),ptitle(1:9),'FontName','Arial','FontSize',10,'FontWeight','bold','location','Northwest')
legend('boxoff')
 
 
ah=axes('position',get(gca,'position'),...
            'visible','off');
 
legend(ah,vel_size(10:12),ptitle((10:12)),'FontName','Arial','FontSize',10,'FontWeight','bold','location','North')
legend('boxoff')
 
%{
ah2=axes('position',get(gca,'position'),...
            'visible','off');
 
legend(ah2,vel_size(11:15),ptitle((11:15)),'FontName','Arial','FontSize',11,'FontWeight','bold','location','Northeast')
legend('boxoff')
%}
 
ax = get(fig10,'CurrentAxes');
set(ax,'Box', 'on');
 
hold off
 
print('-dtiff','-r500',['Sedimentation_Velocity' num2str(FileName)]);
 
 
%The following section which plots the variation of concentration along the
%height is disabled for the sake of enhancing the speed of modelling. 
%This can be enabled again by repeating the simulation with
%spatial variations and assigning the number of delta_x to , say, 20. 
 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plotting concentration variation along the length at different times (plot number):
%Here for each experimental case one separated figure is produced (the maximum number of figures are 8)
for pn=1:PlotNo
    
     if PlotNo>1
        caseNo=pn;
     end 
    
       if pn==1
   fig8=figure;
   ff='fig8';
       elseif pn==2
   fig9=figure;
   ff='fig9';
       elseif pn==3
   fig10=figure;
      ff='fig10';
       elseif pn==4
   fig11=figure;
      ff='fig11';
       elseif pn==5
   fig12=figure;
      ff='fig12';
       elseif pn==6
   fig13=figure;
      ff='fig13';
       elseif pn==7
   fig14=figure;
      ff='fig14';
       elseif pn==8
   fig15=figure;
      ff='fig15';
       end
   
Con=0;
%markers=['o', 's', 'd', '^', 'v', '>','<','h'];
 
for i=1:plotnumber
 
   if pn<6
   color=color1(pn);
 elseif pn==6
    color=[0.5 0.4 0.8];
 elseif pn==7
    color=[0.85 0.30 0.45];
 elseif pn==8
    color=[0.15 0.75 0.85];
 elseif pn==9
    color=[0.9 0.05 0.95];
 elseif pn==10
    color=[0.7 0.6 0.4];
 elseif pn>10
    color=[rand rand rand];
       end
   
ds=dsMat(caseNo);
ds=ds/100;  %m
%Calculation of delta_x
delx=ds/(ndelx);
 
mdp=MeasDep(caseNo); %cm for the beam position in the cuvette placed in the Malvern Zetasizer DLS
mdp=mdp/100;  %m
mdpNdx=round(mdp/delx); %Cell index, which is the place of the measurement.
 
 
   %subscriptt=round(T1/plotnumber*i);
   subscriptt=round(t_indexoutput(dataNo(pn))/plotnumber*i);
   
tmpor = abs(tstartMat(pn,:)-subscriptt);
[idx10 idx10] = min(tmpor); %index of closest value
subscriptt2=idx10; %closest value
 
    %Con(1:ndelx)=ConcMat(pn,subscriptt2,1:ndelx);
 
h8(i)=plot(ConcMat(pn,dataNo(pn),1:ndelx),0:delx*100:(ndelx-1)*delx*100,'Color', color, 'LineWidth', 3);
hold on
 
maxsize8(i)=max(Con);
 
    t8=round(tstartMat(subscriptt2)/60);
    leg8(i)={num2str(t8)};
    
end
 
 
maxmax8=max(maxsize8);
ylimitax8=2*maxmax8;
       if pn==1
ax = get(fig8,'CurrentAxes');
       elseif pn==2
ax = get(fig9,'CurrentAxes');
       elseif pn==3
ax = get(fig10,'CurrentAxes');
       elseif pn==4
ax = get(fig11,'CurrentAxes');
       elseif pn==5
ax = get(fig12,'CurrentAxes');
       elseif pn==6
ax = get(fig13,'CurrentAxes');
       elseif pn==7
ax = get(fig14,'CurrentAxes');
       elseif pn==8
ax = get(fig15,'CurrentAxes');
       end
       
set(ax,'Box', 'on');
%
handles=findobj(gcf);
allaxes=findall(handles,'Type','axes');
alllines=findall(handles,'Type','line','Linestyle', '--');
alltext=findall(handles,'Type','text');
 
set(allaxes,'FontName','Arial','FontWeight','Bold','LineWidth',2);%,...
    %'FontSize',12);
%set(alllines,'Linewidth',2);
%set(alltext,'FontName','Arial','FontWeight','Bold','FontSize',14);
%set(allaxes,'FontName','Arial','FontWeight','Bold');
%
axis([0 1.5 0 inf])
%set(gca,'XTick', 0:200:(x_initial_size_dist(x_dist_data_No)));
%set(gca,'YTick', 0:0.05:ylimitax8+0.035*ylimitax8);
%set(gca, 'XTick', [1 10^1 10^2 10^3 10^4 10^5])
set(gca,'XMinorTick','on','YMinorTick','on')
set(gca,'YDir','Reverse')
 
Leg8Fit(1:plotnumber)={'_ min'};
 
leg(kk+1)={'Total'};
for i=1:plotnumber
legfinal8(i)=strcat(leg8(i),Leg8Fit(i));
end
 
axistitle='C/C_{0}'; 
%grid on
xlabel(axistitle,'FontName','Arial','FontSize',15,'FontWeight','bold');
ylabel('Depth (cm)','FontName','Arial','FontSize',15,'FontWeight','bold');
set(gca,'FontName','times','FontSize',15)
 
legend(h8(1:plotnumber),legfinal8(1:plotnumber),'FontName','t','FontSize',12,'FontWeight','bold','location','northeast')
legend('boxoff');
 
 
 
%{
set(ax, 'YTick', (30:ylimitax));
%}
 
 
 
hold off
print('-dtiff','-r500',['CC0 along the height_' num2str(FileName) num2str(ff)]);
save(['ModelingFile_' num2str(FileName) num2str(ff)]);
end
 
%%
%??????????????????????????????????????????????????????????????????????????%
%Saving the outputs:
%??????????????????????????????????????????????????????????????????????????%
for pn=1:PlotNo
    
 %Input variables from the input data:
    Inputx=Input1(1:dataNo(pn),3*caseNo-2);
    Inputy=Input1(1:dataNo(pn),3*caseNo-1);
    InputErr=Input1(:,3*caseNo);
    InputEr=InputErr;
    L=Inputy(:)<20;
    Inputx(L)=[];
    Inputy(L)=[];
    InputEr(L)=[];
    sizI=size(InputEr);
    
    if pn==1
   columnsheettitle1='A1';
   columnsheettitle2='A2';
    elseif pn==2
   columnsheettitle1='B1';
   columnsheettitle2='B2';  
    elseif pn==3
   columnsheettitle1='C1';
   columnsheettitle2='C2'; 
    elseif pn==4
   columnsheettitle1='D1';
   columnsheettitle2='D2'; 
    elseif pn==5
   columnsheettitle1='E1';
   columnsheettitle2='E2'; 
    elseif pn==6
   columnsheettitle1='F1';
   columnsheettitle2='F2'; 
    elseif pn==7
   columnsheettitle1='H1';
   columnsheettitle2='H2';
     elseif pn==8
   columnsheettitle1='I1';
   columnsheettitle2='I2';
       elseif pn==9
   columnsheettitle1='J1';
   columnsheettitle2='J2';
       elseif pn==10
   columnsheettitle1='K1';
   columnsheettitle2='K2';
       elseif pn==11
   columnsheettitle1='L1';
   columnsheettitle2='L2';
       elseif pn==12
   columnsheettitle1='M1';
   columnsheettitle2='M2';
 
    end
    
    %subscriptt=round(t_indexoutput(ndelt1/deltfac)/plotnumber*i);
    if PlotNo==1
        subscriptt=round(t_indexoutput(dataNo(1))/plotnumber*i);
        xlswrite(OutputFileName,(Inputx(1:dataNo(1))),'Sheet1',columnsheettitle2);
    elseif PlotNo>1
        subscriptt=round(t_indexoutput(dataNo(pn))/plotnumber*i);
        xlswrite(OutputFileName,(Inputx(1:dataNo(pn))),'Sheet1',columnsheettitle2);
    end
        
    snapshot_tt=tMat(subscriptt);
 
 
xlswrite(OutputFileName,ModelMat(:,pn),'Sheet2',columnsheettitle2);
xlswrite(OutputFileName,transpose(ConcOutputMat(pn,:)),'Sheet3',columnsheettitle2);
xlswrite(OutputFileName,transpose(size_ditrib1(pn,:)),'Sheet4',columnsheettitle2);
xlswrite(OutputFileName,transpose(Mass_size_dist1(pn,:)),'Sheet5',columnsheettitle2);
xlswrite(OutputFileName,transpose(Mass_size_dist2(pn,:)),'Sheet6',columnsheettitle2);
xlswrite(OutputFileName,transpose(Mass_size_dist3(pn,:)),'Sheet7',columnsheettitle2);
 
xlswrite(OutputFileName,(ConcInit(1:ndelx,pn)),'Sheet8',columnsheettitle2);
xlswrite(OutputFileName,(ConcMid(1:ndelx,pn)),'Sheet9',columnsheettitle2);
xlswrite(OutputFileName,(ConcEnd(1:ndelx,pn)),'Sheet10',columnsheettitle2);
 
% Columnheader:
coltitle2=['Power Law' 'Simple Fractal' 'Permeability, Davies' 'Permeability, Brinkman' 'Fractal, Size Distribution']; 
colheader=coltitle2(pn);
 
xlswrite(OutputFileName,colheader,'Sheet1',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet2',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet3',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet4',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet5',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet6',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet7',columnsheettitle1); 
 
xlswrite(OutputFileName,colheader,'Sheet8',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet9',columnsheettitle1); 
xlswrite(OutputFileName,colheader,'Sheet10',columnsheettitle1); 
end
 
for pn=1:PlotNo
    if PlotNo>1
        caseNo=pn;
    end
FinalResults(1:9,pn)=[alfMat(caseNo) DfMat(caseNo) deltfacMat(caseNo)...
    finalMassBalanceError(pn)  Rsq(pn)  RsqConc(pn)  RuningTimeMat(pn) LaterSizeTransRatioGeom(pn) deltmagMat(caseNo)];
 
end
 
TableItems={'alfa' 'Df' 'DeltaTFactor' 'MassBalanceErr' 'Rsq' 'Rsq_Conc.' 'RuningTime' 'SizeTransRatioGeom' 'Delt_t_magnification'};
 
dlmwrite(['Rep_Table_' num2str(OutputFileName)],transpose(FinalResults(:,1:PlotNo)),'delimiter',...
        '\t','precision',16,'roffset',1);
 
%printmat(FinalResults, FileName, 'DeltaTFactor IS Zeta Df MassBalanceErr Rsq RuningTime SizeTransRatioGeom', '1 2 3 4 5');
 
%save('Opt_Results.mat', 'Outcomes');
 
Rsqout=Rsq;
RsqConcout=RsqConc;
finalMassBalanceErrorout=finalMassBalanceError;
 
%

